SimpleAplication class

Constructors

SimpleAplication()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hideNavigation(bool hide) Future<bool>
The function hideNavigation in Dart is used to hide or show the system navigation bar.
lockAndUnlockScreen({required bool lock, double aspectRatio = 1.0}) Future<bool>
The function lockAndUnlockScreen locks or unlocks the screen orientation based on the lock parameter and the aspectRatio value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited