SimpleController class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
delete()
→ void
-
⛔ By disposing of the controller
-
dispose()
→ void
-
Discards any resources used by the object.
inherited
-
listenPlayAndPause()
→ Stream<String>
-
⏯️ Returning a current play and pause stream of the video.
-
listenPosition()
→ Stream<Duration>
-
📽️ Returning a stream of the current position of the video.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
pause()
→ void
-
⏸️ Pause video playback
-
play()
→ void
-
▶️ Start playing the video
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateController(VideoPlayerController controller)
→ void
-
⛔ This method should not be called unless you know what it is doing. ☢️