timelineTheme static method
Slim seek bar, in line with what current video players look like: a thin track, a small thumb and a lighter band for the buffered range.
Implementation
static SliderThemeData timelineTheme(Color colorAccent) {
return SliderThemeData(
trackHeight: 3,
activeTrackColor: colorAccent,
inactiveTrackColor: Colors.white24,
secondaryActiveTrackColor: Colors.white38,
thumbColor: colorAccent,
thumbShape: const RoundSliderThumbShape(
enabledThumbRadius: 6,
pressedElevation: 0,
elevation: 0,
),
overlayShape: const RoundSliderOverlayShape(overlayRadius: 14),
overlayColor: colorAccent.withValues(alpha: 0.25),
trackShape: const RoundedRectSliderTrackShape(),
showValueIndicator: ShowValueIndicator.never,
);
}