muteOnAutoPlay property

bool muteOnAutoPlay
final

Starts the video silent when autoPlay kicks in.

While the sound is off the inline player shows a small muted badge the viewer can tap to turn it on. Going full screen turns it on as well.

Implementation

final bool muteOnAutoPlay;